@@ -97,19 +97,58 @@ var _ = Describe("DeviceSelectors", func() {
 		})
 		Context("filtering", func() {
 			It("should return devices matching interface PF name", func() {
-				netDevs := []string{"ens0"}
+				netDevs := []string{"ens0", "ens2f0#1", "ens2f1#0,3-5,7"}
 				sel := newPfNameSelector(netDevs).(*pfNameSelector)
 
 				dev0 := mocks.PciNetDevice{}
 				dev0.On("GetPFName").Return("ens0")
 				dev1 := mocks.PciNetDevice{}
 				dev1.On("GetPFName").Return("eth0")
+				dev2 := mocks.PciNetDevice{}
+				dev2.On("GetPFName").Return("ens2f0")
+				dev2.On("GetVFID").Return(1)
+				dev3 := mocks.PciNetDevice{}
+				dev3.On("GetPFName").Return("ens2f1")
+				dev3.On("GetVFID").Return(0)
+				dev4 := mocks.PciNetDevice{}
+				dev4.On("GetPFName").Return("ens2f1")
+				dev4.On("GetVFID").Return(1)
+				dev5 := mocks.PciNetDevice{}
+				dev5.On("GetPFName").Return("ens2f1")
+				dev5.On("GetVFID").Return(2)
+				dev6 := mocks.PciNetDevice{}
+				dev6.On("GetPFName").Return("ens2f1")
+				dev6.On("GetVFID").Return(3)
+				dev7 := mocks.PciNetDevice{}
+				dev7.On("GetPFName").Return("ens2f1")
+				dev7.On("GetVFID").Return(4)
+				dev8 := mocks.PciNetDevice{}
+				dev8.On("GetPFName").Return("ens2f1")
+				dev8.On("GetVFID").Return(5)
+				dev9 := mocks.PciNetDevice{}
+				dev9.On("GetPFName").Return("ens2f1")
+				dev9.On("GetVFID").Return(6)
+				dev10 := mocks.PciNetDevice{}
+				dev10.On("GetPFName").Return("ens2f1")
+				dev10.On("GetVFID").Return(7)
 
-				in := []types.PciNetDevice{&dev0, &dev1}
+				in := []types.PciNetDevice{&dev0, &dev1, &dev2,
+					&dev3, &dev4, &dev5,
+					&dev6, &dev7, &dev8,
+					&dev9, &dev10}
 				filtered := sel.Filter(in)
 
 				Expect(filtered).To(ContainElement(&dev0))
 				Expect(filtered).NotTo(ContainElement(&dev1))
+				Expect(filtered).To(ContainElement(&dev2))
+				Expect(filtered).To(ContainElement(&dev3))
+				Expect(filtered).NotTo(ContainElement(&dev4))
+				Expect(filtered).NotTo(ContainElement(&dev5))
+				Expect(filtered).To(ContainElement(&dev6))
+				Expect(filtered).To(ContainElement(&dev7))
+				Expect(filtered).To(ContainElement(&dev8))
+				Expect(filtered).NotTo(ContainElement(&dev9))
+				Expect(filtered).To(ContainElement(&dev10))
 			})
 		})
 	})
